@@ -37,9 +37,9 @@ from PyQt4.uic import loadUi
 pygame.init()
 random.seed()
 #Logger einrichten
-logging.basicConfig(filename = "fartyprotokoll.log",
-                    level = logging.INFO,
-                    format = "%(asctime)s [%(levelname)-8s] %(message)s")
+#logging.basicConfig(filename = "fartyprotokoll.log",
+#                    level = logging.INFO,
+#                    format = "%(asctime)s [%(levelname)-8s] %(message)s")
 
 
 #Erstellen der Mainklasse
@@ -49,8 +49,8 @@ class MainWindow(QtGui.QMainWindow):
         QtGui.QMainWindow.__init__(self,parent)
        
         #MainWindow Initialisierung/Laden des Stylesheets
-        logging.info("Farty wurde gestartet")
-        self.ui=loadUi("furzkissen.ui")
+      #  logging.info("Farty wurde gestartet")
+        self.ui=loadUi("/opt/farty/furzkissen.ui")
         self.ui.show()
         self.ui.showFullScreen()
 
@@ -75,38 +75,38 @@ class MainWindow(QtGui.QMainWindow):
     
     def fartrandom(self):#Zufallsmechanismus für Abspielen der Furzsounds 10-81 
         fartnumber=random.randint(10,81)
-        path="Furzsounds/furz0"+str(fartnumber)+".wav"
+        path="/opt/farty/Furzsounds/furz0"+str(fartnumber)+".wav"
         sound=pygame.mixer.Sound(path)
         sound.play()
         pygame.time.delay(200)
-        logging.info("Farty hat den Sound furz0"+str(fartnumber)+".wav gefurzt")
+     #   logging.info("Farty hat den Sound furz0"+str(fartnumber)+".wav gefurzt")
         
        
        
         #time.sleep(1.2) #Führt nach Mehrfachklick zu ewigem Abspielen --> deaktiviert!
        
     def close2(self):#Methode zum Schließen des Mainwindows
-        logging.info("Farty wurde beendet")
+     #   logging.info("Farty wurde beendet")
         sys.exit()
         
     def minimize2(self):#Experimentell, schließt statt zu minimieren
         try:
-            logging.info("Farty wurde minimiert")
+    #        logging.info("Farty wurde minimiert")
             subprocess.Popen(['dbus-send', '--type=signal', '--session', '/com/nokia/hildon_desktop', 'com.nokia.hildon_desktop.exit_app_view'])
                 
         except:
-            logging.error("Farty konnte nicht minimiert werden!")  
+        #    logging.error("Farty konnte nicht minimiert werden!")  
          
     def idea2(self):
-        logging.info("Fartys Infobox wurde aufgerufen")
+    #    logging.info("Fartys Infobox wurde aufgerufen")
         QtGui.QMessageBox.about(self, "Farty the Farter:\n",
                  "Click me, in order to let me fart.\n"
-                 "I can do more than 80 different\n"
+                 "I can do more than 65 different\n"
                  "kind of fart sounds\n"
                  "Have fun and keep farting ;)\n")
         
     def about2(self):
-        logging.info("Fartys QtAboutBox wurde aufgerufen")
+    #    logging.info("Fartys QtAboutBox wurde aufgerufen")
         QtGui.QMessageBox.aboutQt(self)    
         
         
@@ -133,11 +133,7 @@ class MainWindow(QtGui.QMainWindow):
             time.sleep(2)
             i=i+2 
             
-             
-            
-        
-        
-                   
+                            
     
 app = QtGui.QApplication(sys.argv)
 main = MainWindow()
